@@ -4,7 +4,7 @@ stsp.cal=function(y,x){
   res1=data.frame(th=roc1$thresholds,
                   tpf=roc1$sensitivities,
                   fpf=(1-roc1$specificities),
-                  tpm=NA,fpm=NA,amd=NA)
+                  tpm=NA,fpm=NA,tmd=NA)
   auc=as.numeric(roc1$auc)
   return(list(res1=res1,auc=auc))
 }
